@@ -1,2 +1,2 @@
-from djqscsv import (render_to_csv_response, create_csv,  # NOQA
+from djqscsv import (render_to_csv_response, write_csv,  # NOQA
                              generate_filename, CSVException)  # NOQA
